#
# Some of the code in this file was derived from C++ code in the
# SIVIC project, https://github.com/SIVICLab/sivic/tree/master/libs/src
# and as such we have included their BSD statement in this file.
#
# Copyright 2009-2010 The Regents of the University of California.
# All Rights Reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# *   Redistributions of source code must retain the above copyright notice,
#     this list of conditions and the following disclaimer.
# *   Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions and the following disclaimer in the documentation
#     and/or other materials provided with the distribution.
# *   None of the names of any campus of the University of California, the name
#     "The Regents of the University of California," or the names of any of its
#     contributors may be used to endorse or promote products derived from this
#     software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
# OF SUCH DAMAGE.

# Python modules
from __future__ import division

from ctypes import *



def get_pfile_hdr_fields(version):
    """
    This function returs a list of fields for mapping a GE P-file header
    to a ctypes class structure. We define different paddings and variable
    names depending on the software version that created the P-file.
    
    """
    plist = []

    if version == 9:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_short) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_raw_pass_size',     c_int) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_int) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 35764) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 41) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('rhe_patid',                c_char * 13) )
        plist.append( ('rhe_patname',              c_char * 25) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 67) )
        plist.append( ('rhe_reqnum',               c_char * 13) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('rhe_refphy',               c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 79) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 66) )
        plist.append( ('rhe_patnameff',            c_char * 65) )
        plist.append( ('rhe_patidff',              c_char * 65) )
        plist.append( ('rhe_reqnumff',             c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 310) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhs_se_desc',              c_char * 30) )
        plist.append( ('pad_xx',                   c_char * 26) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 257) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 656) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 58) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 21) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 31) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 240) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhi_image_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 100) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )

    elif version == 11:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_raw_pass_size',     c_int) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_int) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 56244) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 41) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('rhe_patid',                c_char * 13) )
        plist.append( ('rhe_patname',              c_char * 25) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 67) )
        plist.append( ('rhe_reqnum',               c_char * 13) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('rhe_refphy',               c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 79) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 66) )
        plist.append( ('rhe_patnameff',            c_char * 65) )
        plist.append( ('rhe_patidff',              c_char * 65) )
        plist.append( ('rhe_reqnumff',             c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 310) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhs_se_desc',              c_char * 30) )
        plist.append( ('pad_xx',                   c_char * 26) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 257) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1164) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 58) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 21) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 31) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 92) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 148) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhi_image_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 100) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )

    elif version == 12:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_raw_pass_size',     c_int) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_int) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 60088) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 75) )
        plist.append( ('rhe_reqnum',               c_char * 13) )
        plist.append( ('rhe_refphy',               c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 105) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 14) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('rhe_patid',                c_char * 13) )
        plist.append( ('rhe_patname',              c_char * 25) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patnameff',            c_char * 65) )
        plist.append( ('rhe_patidff',              c_char * 65) )
        plist.append( ('rhe_reqnumff',             c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 422) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 62) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 74) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1573) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 36) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 170) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 36) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 38) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 14:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_raw_pass_size',     c_uint) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_int) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 139508) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 52) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 91) )
        plist.append( ('rhe_reqnum',               c_char * 13) )
        plist.append( ('rhe_refphy',               c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 105) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 14) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('rhe_patid',                c_char * 13) )
        plist.append( ('rhe_patname',              c_char * 25) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patnameff',            c_char * 65) )
        plist.append( ('rhe_patidff',              c_char * 65) )
        plist.append( ('rhe_reqnumff',             c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 358) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 126) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 122) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1429) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 196) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 306) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 36) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 112) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 15:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_raw_pass_size',     c_uint) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_int) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 139508) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 52) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 91) )
        plist.append( ('rhe_reqnum',               c_char * 13) )
        plist.append( ('rhe_refphy',               c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 105) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 14) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('rhe_patid',                c_char * 13) )
        plist.append( ('rhe_patname',              c_char * 25) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patnameff',            c_char * 65) )
        plist.append( ('rhe_patidff',              c_char * 65) )
        plist.append( ('rhe_reqnumff',             c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 358) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 126) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 122) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1429) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 196) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 306) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 116) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 16:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_raw_pass_size',     c_uint) )
        plist.append( ('pad_xx',                   c_char * 80) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_int) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 139508) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 52) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 91) )
        plist.append( ('rhe_reqnum',               c_char * 13) )
        plist.append( ('rhe_refphy',               c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 105) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 14) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('rhe_patid',                c_char * 13) )
        plist.append( ('rhe_patname',              c_char * 25) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patnameff',            c_char * 65) )
        plist.append( ('rhe_patidff',              c_char * 65) )
        plist.append( ('rhe_reqnumff',             c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 358) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 126) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 122) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1477) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 196) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 306) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 116) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 20:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 116) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_uint) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 188) )
        plist.append( ('rhr_rh_raw_pass_size',     c_longlong) )
        plist.append( ('pad_xx',                   c_char * 141724) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 112) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 335) )
        plist.append( ('rhe_refphy',               c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 198) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 14) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patname',              c_char * 65) )
        plist.append( ('rhe_patid',                c_char * 65) )
        plist.append( ('rhe_reqnum',               c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 928) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 194) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 138) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1705) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 300) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 310) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 130) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 21:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 116) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_uint) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 188) )
        plist.append( ('rhr_rh_raw_pass_size',     c_longlong) )
        plist.append( ('pad_xx',                   c_char * 142272) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 112) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 335) )
        plist.append( ('rhe_refphy',               c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 198) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 14) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patname',              c_char * 65) )
        plist.append( ('rhe_patid',                c_char * 65) )
        plist.append( ('rhe_reqnum',               c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 928) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 194) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 138) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1705) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 300) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 310) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 130) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 23:
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 116) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_uint) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 188) )
        plist.append( ('rhr_rh_raw_pass_size',     c_longlong) )
        plist.append( ('pad_xx',                   c_char * 141724) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 112) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 335) )
        plist.append( ('rhe_refphy',               c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 198) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patname',              c_char * 65) )
        plist.append( ('rhe_patid',                c_char * 65) )
        plist.append( ('rhe_reqnum',               c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 920) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 194) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 138) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1705) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 300) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 310) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 130) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 24:  # 25 and 25.1 same pfile
        plist.append( ('rhr_rh_rdbm_rev',          c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhr_rh_scan_date',         c_char * 10) )
        plist.append( ('rhr_rh_scan_time',         c_char * 8) )
        plist.append( ('rhr_rh_logo',              c_char * 10) )
        plist.append( ('rhr_rh_file_contents',     c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type', c_short) )
        plist.append( ('pad_xx',                   c_char * 6) )
        plist.append( ('rhr_rh_npasses',           c_short) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhr_rh_nslices',           c_short) )
        plist.append( ('pad_xx',                   c_char * 10) )
        plist.append( ('rhr_rh_frame_size',        c_ushort) )
        plist.append( ('rhr_rh_point_size',        c_short) )
        plist.append( ('pad_xx',                   c_char * 116) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',  c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',   c_short) )
        plist.append( ('rhr_rh_user0',             c_float) )
        plist.append( ('rhr_rh_user1',             c_float) )
        plist.append( ('rhr_rh_user2',             c_float) )
        plist.append( ('rhr_rh_user3',             c_float) )
        plist.append( ('rhr_rh_user4',             c_float) )
        plist.append( ('rhr_rh_user5',             c_float) )
        plist.append( ('rhr_rh_user6',             c_float) )
        plist.append( ('rhr_rh_user7',             c_float) )
        plist.append( ('rhr_rh_user8',             c_float) )
        plist.append( ('rhr_rh_user9',             c_float) )
        plist.append( ('rhr_rh_user10',            c_float) )
        plist.append( ('rhr_rh_user11',            c_float) )
        plist.append( ('rhr_rh_user12',            c_float) )
        plist.append( ('rhr_rh_user13',            c_float) )
        plist.append( ('rhr_rh_user14',            c_float) )
        plist.append( ('rhr_rh_user15',            c_float) )
        plist.append( ('rhr_rh_user16',            c_float) )
        plist.append( ('rhr_rh_user17',            c_float) )
        plist.append( ('rhr_rh_user18',            c_float) )
        plist.append( ('rhr_rh_user19',            c_float) )
        plist.append( ('pad_xx',                   c_char * 72) )
        plist.append( ('rhr_spectral_width',       c_float) )
        plist.append( ('rhr_csi_dims',             c_short) )
        plist.append( ('rhr_xcsi',                 c_short) )
        plist.append( ('rhr_ycsi',                 c_short) )
        plist.append( ('rhr_zcsi',                 c_short) )
        plist.append( ('rhr_roilenx',              c_float) )
        plist.append( ('rhr_roileny',              c_float) )
        plist.append( ('rhr_roilenz',              c_float) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',       c_uint) )
        plist.append( ('pad_xx',                   c_char * 560) )
        plist.append( ('rhr_rh_user_usage_tag',    c_uint) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhr_rh_user20',            c_float) )
        plist.append( ('rhr_rh_user21',            c_float) )
        plist.append( ('rhr_rh_user22',            c_float) )
        plist.append( ('rhr_rh_user23',            c_float) )
        plist.append( ('rhr_rh_user24',            c_float) )
        plist.append( ('rhr_rh_user25',            c_float) )
        plist.append( ('rhr_rh_user26',            c_float) )
        plist.append( ('rhr_rh_user27',            c_float) )
        plist.append( ('rhr_rh_user28',            c_float) )
        plist.append( ('rhr_rh_user29',            c_float) )
        plist.append( ('rhr_rh_user30',            c_float) )
        plist.append( ('rhr_rh_user31',            c_float) )
        plist.append( ('rhr_rh_user32',            c_float) )
        plist.append( ('rhr_rh_user33',            c_float) )
        plist.append( ('rhr_rh_user34',            c_float) )
        plist.append( ('rhr_rh_user35',            c_float) )
        plist.append( ('rhr_rh_user36',            c_float) )
        plist.append( ('rhr_rh_user37',            c_float) )
        plist.append( ('rhr_rh_user38',            c_float) )
        plist.append( ('rhr_rh_user39',            c_float) )
        plist.append( ('rhr_rh_user40',            c_float) )
        plist.append( ('rhr_rh_user41',            c_float) )
        plist.append( ('rhr_rh_user42',            c_float) )
        plist.append( ('rhr_rh_user43',            c_float) )
        plist.append( ('rhr_rh_user44',            c_float) )
        plist.append( ('rhr_rh_user45',            c_float) )
        plist.append( ('rhr_rh_user46',            c_float) )
        plist.append( ('rhr_rh_user47',            c_float) )
        plist.append( ('rhr_rh_user48',            c_float) )
        plist.append( ('pad_xx',                   c_char * 352) )
        plist.append( ('rhr_rdb_hdr_off_data',     c_int) )
        plist.append( ('pad_xx',                   c_char * 188) )
        plist.append( ('rhr_rh_raw_pass_size',     c_longlong) )
        plist.append( ('pad_xx',                   c_char * 141724) )
        plist.append( ('rhe_magstrength',          c_int) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_datetime',          c_int) )
        plist.append( ('pad_xx',                   c_char * 112) )
        plist.append( ('rhe_ex_no',                c_ushort) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_patsex',               c_short) )
        plist.append( ('pad_xx',                   c_char * 335) )
        plist.append( ('rhe_refphy',               c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 198) )
        plist.append( ('rhe_ex_sysid',             c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 22) )
        plist.append( ('rhe_hospname',             c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhe_ex_verscre',           c_char * 2) )
        plist.append( ('pad_xx',                   c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',          c_char * 16) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhe_study_uid',            c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhe_patname',              c_char * 65) )
        plist.append( ('rhe_patid',                c_char * 65) )
        plist.append( ('rhe_reqnum',               c_char * 17) )
        plist.append( ('rhe_dateofbirth',          c_char * 9) )
        plist.append( ('pad_xx',                   c_char * 920) )
        plist.append( ('rhs_position',             c_int) )
        plist.append( ('rhs_entry',                c_int) )
        plist.append( ('pad_xx',                   c_char * 194) )
        plist.append( ('rhs_se_no',                c_short) )
        plist.append( ('pad_xx',                   c_char * 138) )
        plist.append( ('rhs_se_desc',              c_char * 65) )
        plist.append( ('pad_xx',                   c_char * 18) )
        plist.append( ('rhs_anref',                c_char * 3) )
        plist.append( ('pad_xx',                   c_char * 27) )
        plist.append( ('rhs_series_uid',           c_char * 32) )
        plist.append( ('rhs_landmark_uid',         c_char * 32) )
        plist.append( ('pad_xx',                   c_char * 1705) )
        plist.append( ('rhi_dfov',                 c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_scanspacing',          c_float) )
        plist.append( ('rhi_loc',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 4) )
        plist.append( ('rhi_nex',                  c_float) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_user0',                c_float) )
        plist.append( ('rhi_user1',                c_float) )
        plist.append( ('rhi_user2',                c_float) )
        plist.append( ('rhi_user3',                c_float) )
        plist.append( ('rhi_user4',                c_float) )
        plist.append( ('rhi_user5',                c_float) )
        plist.append( ('rhi_user6',                c_float) )
        plist.append( ('rhi_user7',                c_float) )
        plist.append( ('rhi_user8',                c_float) )
        plist.append( ('rhi_user9',                c_float) )
        plist.append( ('rhi_user10',               c_float) )
        plist.append( ('rhi_user11',               c_float) )
        plist.append( ('rhi_user12',               c_float) )
        plist.append( ('rhi_user13',               c_float) )
        plist.append( ('rhi_user14',               c_float) )
        plist.append( ('rhi_user15',               c_float) )
        plist.append( ('rhi_user16',               c_float) )
        plist.append( ('rhi_user17',               c_float) )
        plist.append( ('rhi_user18',               c_float) )
        plist.append( ('rhi_user19',               c_float) )
        plist.append( ('rhi_user20',               c_float) )
        plist.append( ('rhi_user21',               c_float) )
        plist.append( ('rhi_user22',               c_float) )
        plist.append( ('pad_xx',                   c_char * 8) )
        plist.append( ('rhi_user23',               c_float) )
        plist.append( ('rhi_user24',               c_float) )
        plist.append( ('pad_xx',                   c_char * 60) )
        plist.append( ('rhi_user25',               c_float) )
        plist.append( ('rhi_user26',               c_float) )
        plist.append( ('rhi_user27',               c_float) )
        plist.append( ('rhi_user28',               c_float) )
        plist.append( ('rhi_user29',               c_float) )
        plist.append( ('rhi_user30',               c_float) )
        plist.append( ('rhi_user31',               c_float) )
        plist.append( ('rhi_user32',               c_float) )
        plist.append( ('rhi_user33',               c_float) )
        plist.append( ('rhi_user34',               c_float) )
        plist.append( ('rhi_user35',               c_float) )
        plist.append( ('rhi_user36',               c_float) )
        plist.append( ('rhi_user37',               c_float) )
        plist.append( ('rhi_user38',               c_float) )
        plist.append( ('rhi_user39',               c_float) )
        plist.append( ('rhi_user40',               c_float) )
        plist.append( ('rhi_user41',               c_float) )
        plist.append( ('rhi_user42',               c_float) )
        plist.append( ('rhi_user43',               c_float) )
        plist.append( ('rhi_user44',               c_float) )
        plist.append( ('rhi_user45',               c_float) )
        plist.append( ('rhi_user46',               c_float) )
        plist.append( ('rhi_user47',               c_float) )
        plist.append( ('rhi_user48',               c_float) )
        plist.append( ('pad_xx',                   c_char * 76) )
        plist.append( ('rhi_ctr_R',                c_float) )
        plist.append( ('rhi_ctr_A',                c_float) )
        plist.append( ('rhi_ctr_S',                c_float) )
        plist.append( ('pad_xx',                   c_char * 12) )
        plist.append( ('rhi_tlhc_R',               c_float) )
        plist.append( ('rhi_tlhc_A',               c_float) )
        plist.append( ('rhi_tlhc_S',               c_float) )
        plist.append( ('rhi_trhc_R',               c_float) )
        plist.append( ('rhi_trhc_A',               c_float) )
        plist.append( ('rhi_trhc_S',               c_float) )
        plist.append( ('rhi_brhc_R',               c_float) )
        plist.append( ('rhi_brhc_A',               c_float) )
        plist.append( ('rhi_brhc_S',               c_float) )
        plist.append( ('pad_xx',                   c_char * 300) )
        plist.append( ('rhi_tr',                   c_int) )
        plist.append( ('rhi_ti',                   c_int) )
        plist.append( ('rhi_te',                   c_int) )
        plist.append( ('pad_xx',                   c_char * 310) )
        plist.append( ('rhi_numecho',              c_short) )
        plist.append( ('pad_xx',                   c_char * 32) )
        plist.append( ('rhi_mr_flip',              c_short) )
        plist.append( ('pad_xx',                   c_char * 20) )
        plist.append( ('rhi_ctyp',                 c_short) )
        plist.append( ('pad_xx',                   c_char * 64) )
        plist.append( ('rhi_freq_dir',             c_short) )
        plist.append( ('pad_xx',                   c_char * 130) )
        plist.append( ('rhi_psdname',              c_char * 33) )
        plist.append( ('pad_xx',                   c_char * 84) )
        plist.append( ('rhi_cname',                c_char * 17) )
        plist.append( ('pad_xx',                   c_char * 51) )
        plist.append( ('rhi_image_uid',            c_char * 32) )

    elif version == 26:
        plist.append( ('rhr_rh_rdbm_rev',           c_float) )
        plist.append( ('rhr_rdb_hdr_off_data',      c_int) )
        plist.append( ('pad_xx',                    c_char * 84) )
        plist.append( ('rhr_rh_scan_date',          c_char * 10) )
        plist.append( ('rhr_rh_scan_time',          c_char * 8) )
        plist.append( ('rhr_rh_logo',               c_char * 10) )
        plist.append( ('rhr_rh_file_contents',      c_short) )
        plist.append( ('pad_xx',                    c_char * 10) )
        plist.append( ('rhr_rh_data_collect_type',  c_short) )
        plist.append( ('pad_xx',                    c_char * 6) )
        plist.append( ('rhr_rh_npasses',            c_short) )
        plist.append( ('pad_xx',                    c_char * 2) )
        plist.append( ('rhr_rh_nslices',            c_short) )
        plist.append( ('pad_xx',                    c_char * 10) )
        plist.append( ('rhr_rh_frame_size',         c_short) )
        plist.append( ('rhr_rh_point_size',         c_short) )
        plist.append( ('pad_xx',                    c_char * 104) )
        plist.append( ('rhr_rh_dab[0]_start_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[0]_stop_rcv',    c_short) )
        plist.append( ('rhr_rh_dab[1]_start_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[1]_stop_rcv',    c_short) )
        plist.append( ('rhr_rh_dab[2]_start_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[2]_stop_rcv',    c_short) )
        plist.append( ('rhr_rh_dab[3]_start_rcv',   c_short) )
        plist.append( ('rhr_rh_dab[3]_stop_rcv',    c_short) )
        plist.append( ('rhr_rh_user0',              c_float) )
        plist.append( ('rhr_rh_user1',              c_float) )
        plist.append( ('rhr_rh_user2',              c_float) )
        plist.append( ('rhr_rh_user3',              c_float) )
        plist.append( ('rhr_rh_user4',              c_float) )
        plist.append( ('rhr_rh_user5',              c_float) )
        plist.append( ('rhr_rh_user6',              c_float) )
        plist.append( ('rhr_rh_user7',              c_float) )
        plist.append( ('rhr_rh_user8',              c_float) )
        plist.append( ('rhr_rh_user9',              c_float) )
        plist.append( ('rhr_rh_user10',             c_float) )
        plist.append( ('rhr_rh_user11',             c_float) )
        plist.append( ('rhr_rh_user12',             c_float) )
        plist.append( ('rhr_rh_user13',             c_float) )
        plist.append( ('rhr_rh_user14',             c_float) )
        plist.append( ('rhr_rh_user15',             c_float) )
        plist.append( ('rhr_rh_user16',             c_float) )
        plist.append( ('rhr_rh_user17',             c_float) )
        plist.append( ('rhr_rh_user18',             c_float) )
        plist.append( ('rhr_rh_user19',             c_float) )
        plist.append( ('pad_xx',                    c_char * 72) )
        plist.append( ('rhr_spectral_width',        c_float) )
        plist.append( ('rhr_csi_dims',              c_short) )
        plist.append( ('rhr_xcsi',                  c_short) )
        plist.append( ('rhr_ycsi',                  c_short) )
        plist.append( ('rhr_zcsi',                  c_short) )
        plist.append( ('rhr_roilenx',               c_float) )
        plist.append( ('rhr_roileny',               c_float) )
        plist.append( ('rhr_roilenz',               c_float) )
        plist.append( ('pad_xx',                    c_char * 32) )
        plist.append( ('rhr_rh_ps_mps_freq',        c_uint) )
        plist.append( ('pad_xx',                    c_char * 432) )
        plist.append( ('rhr_rh_user_usage_tag',     c_uint) )
        plist.append( ('pad_xx',                    c_char * 8) )
        plist.append( ('rhr_rh_user20',             c_float) )
        plist.append( ('rhr_rh_user21',             c_float) )
        plist.append( ('rhr_rh_user22',             c_float) )
        plist.append( ('rhr_rh_user23',             c_float) )
        plist.append( ('rhr_rh_user24',             c_float) )
        plist.append( ('rhr_rh_user25',             c_float) )
        plist.append( ('rhr_rh_user26',             c_float) )
        plist.append( ('rhr_rh_user27',             c_float) )
        plist.append( ('rhr_rh_user28',             c_float) )
        plist.append( ('rhr_rh_user29',             c_float) )
        plist.append( ('rhr_rh_user30',             c_float) )
        plist.append( ('rhr_rh_user31',             c_float) )
        plist.append( ('rhr_rh_user32',             c_float) )
        plist.append( ('rhr_rh_user33',             c_float) )
        plist.append( ('rhr_rh_user34',             c_float) )
        plist.append( ('rhr_rh_user35',             c_float) )
        plist.append( ('rhr_rh_user36',             c_float) )
        plist.append( ('rhr_rh_user37',             c_float) )
        plist.append( ('rhr_rh_user38',             c_float) )
        plist.append( ('rhr_rh_user39',             c_float) )
        plist.append( ('rhr_rh_user40',             c_float) )
        plist.append( ('rhr_rh_user41',             c_float) )
        plist.append( ('rhr_rh_user42',             c_float) )
        plist.append( ('rhr_rh_user43',             c_float) )
        plist.append( ('rhr_rh_user44',             c_float) )
        plist.append( ('rhr_rh_user45',             c_float) )
        plist.append( ('rhr_rh_user46',             c_float) )
        plist.append( ('rhr_rh_user47',             c_float) )
        plist.append( ('rhr_rh_user48',             c_float) )
        plist.append( ('pad_xx',                    c_char * 488) )
        plist.append( ('rhr_rh_raw_pass_size',      c_longlong) )
        plist.append( ('pad_xx',                    c_char * 192684) )
        plist.append( ('rhe_magstrength',           c_int) )
        plist.append( ('pad_xx',                    c_char * 4) )
        plist.append( ('rhe_ex_datetime',           c_int) )
        plist.append( ('pad_xx',                    c_char * 112) )
        plist.append( ('rhe_ex_no',                 c_short) )
        plist.append( ('pad_xx',                    c_char * 22) )
        plist.append( ('rhe_patsex',                c_short) )
        plist.append( ('pad_xx',                    c_char * 335) )
        plist.append( ('rhe_refphy',                c_char * 65) )
        plist.append( ('pad_xx',                    c_char * 198) )
        plist.append( ('rhe_ex_sysid',              c_char * 9) )
        plist.append( ('pad_xx',                    c_char * 22) )
        plist.append( ('rhe_hospname',              c_char * 33) )
        plist.append( ('pad_xx',                    c_char * 4) )
        plist.append( ('rhe_ex_verscre',            c_char * 2) )
        plist.append( ('pad_xx',                    c_char * 2) )
        plist.append( ('rhe_uniq_sys_id',           c_char * 16) )
        plist.append( ('pad_xx',                    c_char * 20) )
        plist.append( ('rhe_study_uid',             c_char * 32) )
        plist.append( ('pad_xx',                    c_char * 64) )
        plist.append( ('rhe_patname',               c_char * 65) )
        plist.append( ('rhe_patid',                 c_char * 65) )
        plist.append( ('rhe_reqnum',                c_char * 17) )
        plist.append( ('rhe_dateofbirth',           c_char * 9) )
        plist.append( ('pad_xx',                    c_char * 920) )
        plist.append( ('rhs_position',              c_int) )
        plist.append( ('rhs_entry',                 c_int) )
        plist.append( ('pad_xx',                    c_char * 88) )
        plist.append( ('rhs_se_no',                 c_int) )
        plist.append( ('pad_xx',                    c_char * 242) )
        plist.append( ('rhs_se_desc',               c_char * 65) )
        plist.append( ('pad_xx',                    c_char * 18) )
        plist.append( ('rhs_anref',                 c_char * 3) )
        plist.append( ('pad_xx',                    c_char * 77) )
        plist.append( ('rhs_series_uid',            c_char * 32) )
        plist.append( ('rhs_landmark_uid',          c_char * 32) )
        plist.append( ('pad_xx',                    c_char * 1655) )
        plist.append( ('rhi_dfov',                  c_float) )
        plist.append( ('pad_xx',                    c_char * 12) )
        plist.append( ('rhi_scanspacing',           c_float) )
        plist.append( ('rhi_loc',                   c_float) )
        plist.append( ('pad_xx',                    c_char * 4) )
        plist.append( ('rhi_nex',                   c_float) )
        plist.append( ('pad_xx',                    c_char * 20) )
        plist.append( ('rhi_user0',                 c_float) )
        plist.append( ('rhi_user1',                 c_float) )
        plist.append( ('rhi_user2',                 c_float) )
        plist.append( ('rhi_user3',                 c_float) )
        plist.append( ('rhi_user4',                 c_float) )
        plist.append( ('rhi_user5',                 c_float) )
        plist.append( ('rhi_user6',                 c_float) )
        plist.append( ('rhi_user7',                 c_float) )
        plist.append( ('rhi_user8',                 c_float) )
        plist.append( ('rhi_user9',                 c_float) )
        plist.append( ('rhi_user10',                c_float) )
        plist.append( ('rhi_user11',                c_float) )
        plist.append( ('rhi_user12',                c_float) )
        plist.append( ('rhi_user13',                c_float) )
        plist.append( ('rhi_user14',                c_float) )
        plist.append( ('rhi_user15',                c_float) )
        plist.append( ('rhi_user16',                c_float) )
        plist.append( ('rhi_user17',                c_float) )
        plist.append( ('rhi_user18',                c_float) )
        plist.append( ('rhi_user19',                c_float) )
        plist.append( ('rhi_user20',                c_float) )
        plist.append( ('rhi_user21',                c_float) )
        plist.append( ('rhi_user22',                c_float) )
        plist.append( ('pad_xx',                    c_char * 8) )
        plist.append( ('rhi_user23',                c_float) )
        plist.append( ('rhi_user24',                c_float) )
        plist.append( ('pad_xx',                    c_char * 60) )
        plist.append( ('rhi_user25',                c_float) )
        plist.append( ('rhi_user26',                c_float) )
        plist.append( ('rhi_user27',                c_float) )
        plist.append( ('rhi_user28',                c_float) )
        plist.append( ('rhi_user29',                c_float) )
        plist.append( ('rhi_user30',                c_float) )
        plist.append( ('rhi_user31',                c_float) )
        plist.append( ('rhi_user32',                c_float) )
        plist.append( ('rhi_user33',                c_float) )
        plist.append( ('rhi_user34',                c_float) )
        plist.append( ('rhi_user35',                c_float) )
        plist.append( ('rhi_user36',                c_float) )
        plist.append( ('rhi_user37',                c_float) )
        plist.append( ('rhi_user38',                c_float) )
        plist.append( ('rhi_user39',                c_float) )
        plist.append( ('rhi_user40',                c_float) )
        plist.append( ('rhi_user41',                c_float) )
        plist.append( ('rhi_user42',                c_float) )
        plist.append( ('rhi_user43',                c_float) )
        plist.append( ('rhi_user44',                c_float) )
        plist.append( ('rhi_user45',                c_float) )
        plist.append( ('rhi_user46',                c_float) )
        plist.append( ('rhi_user47',                c_float) )
        plist.append( ('rhi_user48',                c_float) )
        plist.append( ('pad_xx',                    c_char * 76) )
        plist.append( ('rhi_ctr_R',                 c_float) )
        plist.append( ('rhi_ctr_A',                 c_float) )
        plist.append( ('rhi_ctr_S',                 c_float) )
        plist.append( ('pad_xx',                    c_char * 12) )
        plist.append( ('rhi_tlhc_R',                c_float) )
        plist.append( ('rhi_tlhc_A',                c_float) )
        plist.append( ('rhi_tlhc_S',                c_float) )
        plist.append( ('rhi_trhc_R',                c_float) )
        plist.append( ('rhi_trhc_A',                c_float) )
        plist.append( ('rhi_trhc_S',                c_float) )
        plist.append( ('rhi_brhc_R',                c_float) )
        plist.append( ('rhi_brhc_A',                c_float) )
        plist.append( ('rhi_brhc_S',                c_float) )
        plist.append( ('pad_xx',                    c_char * 300) )
        plist.append( ('rhi_tr',                    c_int) )
        plist.append( ('rhi_ti',                    c_int) )
        plist.append( ('rhi_te',                    c_int) )
        plist.append( ('pad_xx',                    c_char * 40) )
        plist.append( ('rhi_rawrunnum',             c_int) )
        plist.append( ('pad_xx',                    c_char * 266) )
        plist.append( ('rhi_numecho',               c_short) )
        plist.append( ('pad_xx',                    c_char * 32) )
        plist.append( ('rhi_mr_flip',               c_short) )
        plist.append( ('pad_xx',                    c_char * 20) )
        plist.append( ('rhi_ctyp',                  c_short) )
        plist.append( ('pad_xx',                    c_char * 64) )
        plist.append( ('rhi_freq_dir',              c_short) )
        plist.append( ('pad_xx',                    c_char * 130) )
        plist.append( ('rhi_psdname',               c_char * 33) )
        plist.append( ('pad_xx',                    c_char * 84) )
        plist.append( ('rhi_cname',                 c_char * 17) )
        plist.append( ('pad_xx',                    c_char * 51) )
        plist.append( ('rhi_image_uid',             c_char * 32) )




    return plist
        



#        else if ( (int)(this->pfileVersion) == 26 ) {
#
#         offsets.assign (" \
#             rhr.rh_rdbm_rev                    , FLOAT_4, 1   , 0,\
#             rhr.rh_scan_date                   , CHAR   , 10  , 92,\
#             rhr.rh_scan_time                   , CHAR   , 8   , 102,\
#             rhr.rh_npasses                     , INT_2  , 1   , 140,\
#             rhr.rh_nslices                     , UINT_2 , 1   , 144,\
#             rhr.csi_dims                       , INT_2  , 1   , 436,\
#             rhr.rh_dab[0].start_rcv            , INT_2  , 1   , 264,\
#             rhr.rh_dab[0].stop_rcv             , INT_2  , 1   , 266,\
#             rhr.rh_dab[1].start_rcv            , INT_2  , 1   , 268,\
#             rhr.rh_dab[1].stop_rcv             , INT_2  , 1   , 270,\
#             rhr.rh_dab[2].start_rcv            , INT_2  , 1   , 272,\
#             rhr.rh_dab[2].stop_rcv             , INT_2  , 1   , 274,\
#             rhr.rh_dab[3].start_rcv            , INT_2  , 1   , 276,\
#             rhr.rh_dab[3].stop_rcv             , INT_2  , 1   , 278,\
#             rhr.rh_data_collect_type           , INT_2  , 1   , 132,\
#             rhr.rh_file_contents               , INT_2  , 1   , 120,\
#             rhr.rdb_hdr_off_data               , INT_4  , 1   , 4,\
#             rhr.rh_frame_size                  , UINT_2 , 1   , 156,\
#             rhr.rh_point_size                  , INT_2  , 1   , 158,\
#             rhr.rh_ps_mps_freq                 , UINT_4 , 1   , 488,\
#             rhr.rh_user_usage_tag              , UINT_4 , 1   , 924,\
#             rhr.roilenx                        , FLOAT_4, 1   , 444,\
#             rhr.roileny                        , FLOAT_4, 1   , 448,\
#             rhr.roilenz                        , FLOAT_4, 1   , 452,\
#             rhr.spectral_width                 , FLOAT_4, 1   , 432,\
#             rhr.xcsi                           , INT_2  , 1   , 438,\
#             rhr.ycsi                           , INT_2  , 1   , 440,\
#             rhr.zcsi                           , INT_2  , 1   , 442,\
#             rhr.rh_logo                        , CHAR   , 10  , 110,\
#             rhr.rh_raw_pass_size               , LINT_8 , 1   , 1540,\
#             rhr.rh_user0                       , FLOAT_4, 1   , 280,\
#             rhr.rh_user1                       , FLOAT_4, 1   , 284,\
#             rhr.rh_user2                       , FLOAT_4, 1   , 288,\
#             rhr.rh_user3                       , FLOAT_4, 1   , 292,\
#             rhr.rh_user4                       , FLOAT_4, 1   , 296,\
#             rhr.rh_user5                       , FLOAT_4, 1   , 300,\
#             rhr.rh_user6                       , FLOAT_4, 1   , 304,\
#             rhr.rh_user7                       , FLOAT_4, 1   , 308,\
#             rhr.rh_user8                       , FLOAT_4, 1   , 312,\
#             rhr.rh_user9                       , FLOAT_4, 1   , 316,\
#             rhr.rh_user10                      , FLOAT_4, 1   , 320,\
#             rhr.rh_user11                      , FLOAT_4, 1   , 324,\
#             rhr.rh_user12                      , FLOAT_4, 1   , 328,\
#             rhr.rh_user13                      , FLOAT_4, 1   , 332,\
#             rhr.rh_user14                      , FLOAT_4, 1   , 336,\
#             rhr.rh_user15                      , FLOAT_4, 1   , 340,\
#             rhr.rh_user16                      , FLOAT_4, 1   , 344,\
#             rhr.rh_user17                      , FLOAT_4, 1   , 348,\
#             rhr.rh_user18                      , FLOAT_4, 1   , 352,\
#             rhr.rh_user19                      , FLOAT_4, 1   , 356,\
#             rhr.rh_user20                      , FLOAT_4, 1   , 936,\
#             rhr.rh_user21                      , FLOAT_4, 1   , 940,\
#             rhr.rh_user22                      , FLOAT_4, 1   , 944,\
#             rhr.rh_user23                      , FLOAT_4, 1   , 948,\
#             rhr.rh_user24                      , FLOAT_4, 1   , 952,\
#             rhr.rh_user25                      , FLOAT_4, 1   , 956,\
#             rhr.rh_user26                      , FLOAT_4, 1   , 960,\
#             rhr.rh_user27                      , FLOAT_4, 1   , 964,\
#             rhr.rh_user28                      , FLOAT_4, 1   , 968,\
#             rhr.rh_user29                      , FLOAT_4, 1   , 972,\
#             rhr.rh_user30                      , FLOAT_4, 1   , 976,\
#             rhr.rh_user31                      , FLOAT_4, 1   , 980,\
#             rhr.rh_user32                      , FLOAT_4, 1   , 984,\
#             rhr.rh_user33                      , FLOAT_4, 1   , 988,\
#             rhr.rh_user34                      , FLOAT_4, 1   , 992,\
#             rhr.rh_user35                      , FLOAT_4, 1   , 996,\
#             rhr.rh_user36                      , FLOAT_4, 1   , 1000,\
#             rhr.rh_user37                      , FLOAT_4, 1   , 1004,\
#             rhr.rh_user38                      , FLOAT_4, 1   , 1008,\
#             rhr.rh_user39                      , FLOAT_4, 1   , 1012,\
#             rhr.rh_user40                      , FLOAT_4, 1   , 1016,\
#             rhr.rh_user41                      , FLOAT_4, 1   , 1020,\
#             rhr.rh_user42                      , FLOAT_4, 1   , 1024,\
#             rhr.rh_user43                      , FLOAT_4, 1   , 1028,\
#             rhr.rh_user44                      , FLOAT_4, 1   , 1032,\
#             rhr.rh_user45                      , FLOAT_4, 1   , 1036,\
#             rhr.rh_user46                      , FLOAT_4, 1   , 1040,\
#             rhr.rh_user47                      , FLOAT_4, 1   , 1044,\
#             rhr.rh_user48                      , FLOAT_4, 1   , 1048,\
#             rhi.psdname                        , CHAR   , 33  , 199812,\
#             rhi.scanspacing                    , FLOAT_4, 1   , 198500,\
#             rhi.te                             , INT_4  , 1   , 199244,\
#             rhi.ti                             , INT_4  , 1   , 199240,\
#             rhi.tr                             , INT_4  , 1   , 199236,\
#             rhi.tlhc_A                         , FLOAT_4, 1   , 198904,\
#             rhi.tlhc_R                         , FLOAT_4, 1   , 198900,\
#             rhi.tlhc_S                         , FLOAT_4, 1   , 198908,\
#             rhi.t                              , INT_4  , 1   , 199236,\
#             rhi.trhc_A                         , FLOAT_4, 1   , 198916,\
#             rhi.trhc_R                         , FLOAT_4, 1   , 198912,\
#             rhi.trhc_S                         , FLOAT_4, 1   , 198920,\
#             rhi.user0                          , FLOAT_4, 1   , 198536,\
#             rhi.user1                          , FLOAT_4, 1   , 198540,\
#             rhi.user2                          , FLOAT_4, 1   , 198544,\
#             rhi.user3                          , FLOAT_4, 1   , 198548,\
#             rhi.user4                          , FLOAT_4, 1   , 198552,\
#             rhi.user5                          , FLOAT_4, 1   , 198556,\
#             rhi.user6                          , FLOAT_4, 1   , 198560,\
#             rhi.user7                          , FLOAT_4, 1   , 198564,\
#             rhi.user8                          , FLOAT_4, 1   , 198568,\
#             rhi.user9                          , FLOAT_4, 1   , 198572,\
#             rhi.user10                         , FLOAT_4, 1   , 198576,\
#             rhi.user11                         , FLOAT_4, 1   , 198580,\
#             rhi.user12                         , FLOAT_4, 1   , 198584,\
#             rhi.user13                         , FLOAT_4, 1   , 198588,\
#             rhi.user14                         , FLOAT_4, 1   , 198592,\
#             rhi.user15                         , FLOAT_4, 1   , 198596,\
#             rhi.user16                         , FLOAT_4, 1   , 198600,\
#             rhi.user17                         , FLOAT_4, 1   , 198604,\
#             rhi.user18                         , FLOAT_4, 1   , 198608,\
#             rhi.user19                         , FLOAT_4, 1   , 198612,\
#             rhi.user20                         , FLOAT_4, 1   , 198616,\
#             rhi.user21                         , FLOAT_4, 1   , 198620,\
#             rhi.user22                         , FLOAT_4, 1   , 198624,\
#             rhi.user23                         , FLOAT_4, 1   , 198636,\
#             rhi.user24                         , FLOAT_4, 1   , 198640,\
#             rhi.user25                         , FLOAT_4, 1   , 198704,\
#             rhi.user26                         , FLOAT_4, 1   , 198708,\
#             rhi.user27                         , FLOAT_4, 1   , 198712,\
#             rhi.user28                         , FLOAT_4, 1   , 198716,\
#             rhi.user29                         , FLOAT_4, 1   , 198720,\
#             rhi.user30                         , FLOAT_4, 1   , 198724,\
#             rhi.user31                         , FLOAT_4, 1   , 198728,\
#             rhi.user32                         , FLOAT_4, 1   , 198732,\
#             rhi.user33                         , FLOAT_4, 1   , 198736,\
#             rhi.user34                         , FLOAT_4, 1   , 198740,\
#             rhi.user35                         , FLOAT_4, 1   , 198744,\
#             rhi.user36                         , FLOAT_4, 1   , 198748,\
#             rhi.user37                         , FLOAT_4, 1   , 198752,\
#             rhi.user38                         , FLOAT_4, 1   , 198756,\
#             rhi.user39                         , FLOAT_4, 1   , 198760,\
#             rhi.user40                         , FLOAT_4, 1   , 198764,\
#             rhi.user41                         , FLOAT_4, 1   , 198768,\
#             rhi.user42                         , FLOAT_4, 1   , 198772,\
#             rhi.user43                         , FLOAT_4, 1   , 198776,\
#             rhi.user44                         , FLOAT_4, 1   , 198780,\
#             rhi.user45                         , FLOAT_4, 1   , 198784,\
#             rhi.user46                         , FLOAT_4, 1   , 198788,\
#             rhi.user47                         , FLOAT_4, 1   , 198792,\
#             rhi.user48                         , FLOAT_4, 1   , 198796,\
#             rhi.cname                          , CHAR   , 17  , 199929,\
#             rhi.brhc_A                         , FLOAT_4, 1   , 198928,\
#             rhi.brhc_R                         , FLOAT_4, 1   , 198924,\
#             rhi.brhc_S                         , FLOAT_4, 1   , 198932,\
#             rhi.ctr_A                          , FLOAT_4, 1   , 198880,\
#             rhi.ctr_R                          , FLOAT_4, 1   , 198876,\
#             rhi.ctr_S                          , FLOAT_4, 1   , 198884,\
#             rhi.dfov                           , FLOAT_4, 1   , 198484,\
#             rhi.freq_dir                       , INT_2  , 1   , 199680,\
#             rhi.ctyp                           , INT_2  , 1   , 199614,\
#             rhi.loc                            , FLOAT_4, 1   , 198504,\
#             rhi.mr_flip                        , INT_2  , 1   , 199592,\
#             rhi.nex                            , FLOAT_4, 1   , 198512,\
#             rhi.numecho                        , INT_2  , 1   , 199558,\
#             rhi.image_uid                      , UID    , 32  , 199997,\
#             rhi.rawrunnum                      , INT_4  , 1   , 199288,\
#             rhe.ex_datetime                    , INT_4  , 1   , 194240,\
#             rhe.ex_no                          , UINT_2 , 1   , 194356,\
#             rhe.magstrength                    , INT_4  , 1   , 194232,\
#             rhe.patid                          , CHAR   , 65  , 195249,\
#             rhe.patname                        , CHAR   , 65  , 195184,\
#             rhe.refphy                         , CHAR   , 65  , 194717,\
#             rhe.reqnum                         , CHAR   , 17  , 195314,\
#             rhe.study_uid                      , UID    , 32  , 195088,\
#             rhe.dateofbirth                    , CHAR   , 9   , 195331,\
#             rhe.patsex                         , INT_2  , 1   , 194380,\
#             rhe.hospname                       , CHAR   , 33  , 195011,\
#             rhe.ex_sysid                       , CHAR   , 9   , 194980,\
#             rhe.uniq_sys_id                    , CHAR   , 16  , 195052,\
#             rhe.ex_verscre                     , CHAR   , 2   , 195048,\
#             rhs.se_no                          , INT_4  , 1   , 196356,\
#             rhs.se_desc                        , CHAR   , 65  , 196602,\
#             rhs.entry                          , INT_4  , 1   , 196264,\
#             rhs.position                       , INT_4  , 1   , 196260,\
#             rhs.series_uid                     , UID    , 32  , 196765,\
#             rhs.landmark_uid                   , UID    , 32  , 196797,\
#             rhs.anref                          , CHAR   , 3   , 196685,\


